@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.6
+# Version: 0.6.1
 # File   : AdvancedContent.module.php
 # Purpose: initial module class. this is the interface to the Module API
 # License: GPL
@@ -41,16 +41,17 @@ class AdvancedContent extends CMSModule
 	
 	function GetVersion() 
 	{
-		return '0.6';
+		return '0.6.1';
 	}
 	
 	function GetHelp() 
 	{
-		$path = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR;
-		if(file_exists($path . 'help_' . $this->curlang . '.html'))
-			return file_get_contents($path . 'help_' . $this->curlang . '.html');
-		else
-			return file_get_contents($path . 'help_en_US.html');
+		#$path = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR;
+		#if(file_exists($path . 'help_' . $this->curlang . '.html'))
+		#	return file_get_contents($path . 'help_' . $this->curlang . '.html');
+		#else
+		#	return file_get_contents($path . 'help_en_US.html');
+		return $this->lang('help');
 	}
 	
 	function GetAuthor() 
@@ -65,10 +66,11 @@ class AdvancedContent extends CMSModule
 	
 	function GetChangeLog() 
 	{
-		$changelog = dirname(__FILE__) . DIRECTORY_SEPARATOR . 
-			'doc' . DIRECTORY_SEPARATOR . 'changelog.html';
-		if(file_exists($changelog))
-			return file_get_contents($changelog);
+		#$changelog = dirname(__FILE__) . DIRECTORY_SEPARATOR . 
+		#	'doc' . DIRECTORY_SEPARATOR . 'changelog.html';
+		#if(file_exists($changelog))
+		#	return file_get_contents($changelog);
+		return $this->lang('changelog');
 	}
 	
 	function HasContentType() 
@@ -187,10 +189,110 @@ class AdvancedContent extends CMSModule
 				$_params['submit'] = true;
 				$this->Redirect($id, 'defaultadmin', $returnid, $_params);
 				break;
+			
+			case 'deleteMultiInput':
+				$items        = array();
+				$_params      = array();
+				$message      = '';
+				$errormessage = '';
+				if(isset($params['input_id']))
+				{
+					$items[] = $params['input_id'];
+				}
+				else if(isset($params['submit_bulkaction']))
+				{
+					foreach($params as $param_name => $param_value)
+					{
+						if(startswith($param_name,'multi_input-'))
+						{
+							$items[] = $param_value;
+						}
+					}
+				}
+				if($this->DeleteMultiInput($items))
+				{
+					$_params['message'] = 'multi_input_deleted';
+					$message .= $this->lang('multi_input_deleted') . "<br />";
+				}
+				else
+				{
+					$_params['errormessage'] = 'error_delete_multi_input';
+					$errormessage .= $this->lang('error_delete_multi_input') . "<br />";
+				}
+				if(!$this->DeleteTplAssoc('multi_input',$items))
+				{
+					$_params['message'] = 'error_delete_multi_input_tpl_assocs';
+					$errormessage .= $this->lang('error_delete_multi_input_tpl_assocs'). "<br />";
+				}
+				$_params['active_tab'] = 'multi_input';
+				
+				if(isset($params['ajax'])) 
+				{
+					@ob_end_clean();
+					@ob_start();
+					if($errormessage) 
+					{
+						echo '<div class="pageerrorcontainer"><ul class="pageerror"><li>'. $errormessage . '</li></ul></div>';
+					}
+					if($message) 
+					{
+						echo '<div class="pagemcontainer"><p class="pagemessage">'.$message.'</p></div>';
+					}
+					ob_end_flush();
+					exit;
+				}
+				
+				$this->Redirect($id, 'defaultadmin', $returnid, $_params);
+				break;
+			
+			case 'deleteMultiInputTpl':
+				$_params = array();
+				$message      = '';
+				$errormessage = '';
+				if(isset($params['tpl_id']))
+				{
+					$this->DeleteTemplate($params['tpl_id']);
+					$_params['message'] = 'multi_input_tpl_deleted';
+					$message .= $this->lang('multi_input_tpl_deleted') . "<br />";
+				}
+				else if(isset($params['submit_bulkaction']))
+				{
+					foreach($params as $param_name => $param_value)
+					{
+						if(startswith($param_name,'multi_input_tpl-'))
+						{
+							$this->DeleteTemplate($param_value);
+							$_params['message'] = 'multi_input_tpl_deleted';
+							$message .= $this->lang('multi_input_tpl_deleted') . "<br />";
+						}
+					}
+				}
+				$_params['active_tab'] = 'multi_input_tpl';
+				if(isset($params['ajax'])) 
+				{
+					@ob_end_clean();
+					@ob_start();
+					if($errormessage) 
+					{
+						echo '<div class="pageerrorcontainer"><ul class="pageerror"><li>'. $errormessage . '</li></ul></div>';
+					}
+					if($message) 
+					{
+						echo '<div class="pagemcontainer"><p class="pagemessage">'.$message.'</p></div>';
+					}
+					ob_end_flush();
+					exit;
+				}
+				$this->Redirect($id, 'defaultadmin', $returnid, $_params);
+				break;
 				
 			case 'default':
 			case 'savePrefs':
 			case 'defaultadmin':
+			case 'addMultiInput':
+			case 'editMultiInput':
+			case 'addMultiInputTpl':
+			case 'editMultiInputTpl':
 				parent::DoAction($action, $id, $params, $returnid);
 				break;
 			default: break;
@@ -199,7 +301,6 @@ class AdvancedContent extends CMSModule
 	
 	function DoEvent($originator, $eventname, &$params) 
 	{
-		$gCms = cmsms();
 		$redirect = false;
 		$db =& $this->GetDb();
 		// get all content of type advanced that need to be set to active/inactive
@@ -245,13 +346,13 @@ class AdvancedContent extends CMSModule
 		}
 		if(count($contents)) 
 		{
-			$gCms->smarty->clear_all_cache();
+			cmsms()->GetSmarty()->clear_all_cache();
 			foreach($contents as $contentId=>$active) 
 			{
 				$query = "UPDATE ". cms_db_prefix() . "content 
 					SET active = ? WHERE content_id = ?";
 				$dbresult = $db->Execute($query, array($active, $contentId));
-				if($contentId == $gCms->variables['pageinfo']->content_id)
+				if($contentId == cmsms()->variables['pageinfo']->content_id)
 					$redirect = $contentId;
 			}
 		}
@@ -261,12 +362,12 @@ class AdvancedContent extends CMSModule
 			return;
 		}
 		$access = true;
-		if( $feusers =& $this->GetModuleInstance('FrontEndUsers' ) && $gCms->smarty->_tpl_vars['content_obj']->mType == 'content2') {
-			$feuAccess = $this->CleanArray(explode(';',$gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['feu_access']));
+		if( $feusers =& $this->GetModuleInstance('FrontEndUsers' ) && cmsms()->GetSmarty()->get_template_vars('content_obj')->Type() == 'content2') {
+			$feuAccess = $this->CleanArray(explode(';',cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_access')));
 			if(!empty($feuAccess)) 
 			{
 				// if page has no parents but inheritance -> remove inheritance (should never happen but just in case)
-				if($gCms->smarty->_tpl_vars['content_obj']->mParentId <= 0 && in_array("-1",$feuAccess)) 
+				if(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId() <= 0 && in_array("-1",$feuAccess)) 
 				{
 					foreach($feuAccess as $k=>$v) 
 					{
@@ -278,7 +379,7 @@ class AdvancedContent extends CMSModule
 				if(in_array('-1',$feuAccess)) 
 				{
 					// ... finally inherit
-					$feuAccess = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,'feu_access',$feuAccess);
+					$feuAccess = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'feu_access',$feuAccess);
 				}
 				
 				// if we have access for certain feu groups only ...
@@ -307,29 +408,29 @@ class AdvancedContent extends CMSModule
 		if(!$access) 
 		{
 			// get the page to redirect to
-			$redirectPage = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['redirect_page'];
+			$redirectPage = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('redirect_page');
 			if($redirectPage == '-1')
-				$redirectPage = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,'redirect_page');
+				$redirectPage = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'redirect_page');
 			
 			// do not redirect to current page -> will result in endless recursive redirection
 			if($redirectPage == $returnid || $redirectPage == $pageinfo->content_id || $redirectPage == $pageinfo->content_alias)
 				$redirectPage = '';
 			
 			// get feu action
-			$feuAction = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['feu_action'];
+			$feuAction = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_action');
 			
 			if($feuAction == '-1')
-				$feuAction = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,'feu_action');
+				$feuAction = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'feu_action');
 			
 			// if we still don't have a redirect page -> do feu action in current page
 			if($redirectPage == '') 
 			{
 				// if we want an action (and we have not done this before) ...
-				if($feuAction && $mainContent && !isset($gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['feu_action_flag'])) 
+				if($feuAction && $mainContent && !cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_action_flag')) 
 				{
 					// ... set a flag that we already have a login form now (just to prevent to display it again for other content blocks) ...
-					$gCms->smarty->_tpl_vars['content_obj']->AddExtraProperty("feu_action_flag");
-					$gCms->smarty->_tpl_vars['content_obj']->SetPropertyValue("feu_action_flag", true);
+					cmsms()->GetSmarty()->get_template_vars('content_obj')->AddExtraProperty("feu_action_flag");
+					cmsms()->GetSmarty()->get_template_vars('content_obj')->SetPropertyValue("feu_action_flag", true);
 					// ... and finally do feu action
 					return $feusers->DoAction('default', 'cntnt01', array('form'=>'login'), $returnid);
 				}
@@ -345,8 +446,8 @@ class AdvancedContent extends CMSModule
 			{
 				// get the redirect params
 				$pattern        = '/([\w]+)=(["][^"]*["]|[\'][^\']*[\']|[^\'"\s]*)/';
-				$redirectParams = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['redirect_params'];
-				$evaluateSmarty = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['evaluate_smarty'];
+				$redirectParams = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('redirect_params');
+				$evaluateSmarty = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('evaluate_smarty');
 				if($evaluateSmarty)
 					$redirectParams = $this->ProcessTemplateFromData($redirectParams);
 				
@@ -372,37 +473,38 @@ class AdvancedContent extends CMSModule
 				}
 				else {
 					// ... otherwise just redirect
-					$manager =& $gCms->GetHierarchyManager();
+					$manager =& cmsms()->GetHierarchyManager();
 					$node    =& $manager->sureGetNodeByAlias($redirectPage);
 					$content =& $node->GetContent();
 					if (isset($content) && $url = $content->GetURL()) 
 					{
+						$config = cmsms()->GetConfig();
 						if(!empty($_params1) && !empty($_params2)) {
-							if($gCms->config['url_rewriting'] == 'none') 
+							if($config['url_rewriting'] == 'none') 
 							{
-								if($content->mDefaultContent)
+								if($content->DefaultContent())
 									$url .= 'index.php?' . implode('&',$_params2);
 								else
 									$url .= '&' . implode('&',$_params2);
 							}
-							else if($gCms->config['url_rewriting'] == 'internal') 
+							else if($config['url_rewriting'] == 'internal') 
 							{
-								if($content->mDefaultContent)
-									$url .= 'index.php/' . implode('/',$_params1) . '/' . $content->mAlias . $gCms->config['page_extension'];
+								if($content->DefaultContent())
+									$url .= 'index.php/' . implode('/',$_params1) . '/' . $content->Alias() . $config['page_extension'];
 								else 
 								{
-									$url = str_replace($gCms->config['root_url'],
-										$gCms->config['root_url'] . '/'. implode('/',$_params1),
+									$url = str_replace($config['root_url'],
+										$config['root_url'] . '/'. implode('/',$_params1),
 										$url);
 								}
 							}
-							else if($gCms->config['url_rewriting'] == 'mod_rewrite') 
+							else if($config['url_rewriting'] == 'mod_rewrite') 
 							{
-								$url = str_replace($gCms->config['root_url'],
-									$gCms->config['root_url'] . '/'. implode('/',$_params1),
+								$url = str_replace($config['root_url'],
+									$config['root_url'] . '/'. implode('/',$_params1),
 									$url);
-								if($content->mDefaultContent)
-									$url .= $content->mAlias . $gCms->config['page_extension'];
+								if($content->DefaultContent())
+									$url .= $content->Alias() . $config['page_extension'];
 							}
 						}
 						$this->RedirectContent($redirect);
@@ -426,10 +528,11 @@ class AdvancedContent extends CMSModule
 		$this->SetParameterType('evaluate_smarty',CLEAN_INT);
 		$this->SetParameterType('item_display',CLEAN_INT);
 		$this->SetParameterType('item_type',CLEAN_STRING);
-		$this->SetParameterType('content_id',CLEAN_INT);
+		$this->SetParameterType('item_id',CLEAN_STRING);
 		$this->SetParameterType('block_id',CLEAN_STRING);
 		$this->SetParameterType('group_id',CLEAN_STRING);
-		$this->SetParameterType('tpl_id',CLEAN_INT);
+		$this->SetParameterType('template_id',CLEAN_INT);
+		$this->SetParameterType('content_id',CLEAN_INT);
 		$this->SetParameterType('ajax',CLEAN_INT);
 		$this->SetParameterType('feu_action',CLEAN_INT);
 		$this->SetParameterType('feu_access',CLEAN_STRING);
@@ -495,6 +598,13 @@ class AdvancedContent extends CMSModule
 		$this->SetParameterType('message_display_settings',CLEAN_STRING);
 		$this->SetParameterType('group_display_settings',CLEAN_STRING);
 		$this->SetParameterType('show_advancedcontent_options',CLEAN_INT);
+		$this->SetParameterType('input_id',CLEAN_STRING);
+		$this->SetParameterType('input_fields',CLEAN_STRING);
+		$this->SetParameterType('submit_bulkaction',CLEAN_INT);
+		
+		$this->SetParameterType('inputs',CLEAN_STRING);
+		$this->SetParameterType('input_delimiter',CLEAN_STRING);
+		$this->SetParameterType('value_delimiter',CLEAN_STRING);
 	}
 	
 	
@@ -766,15 +876,18 @@ class AdvancedContent extends CMSModule
 		}
 		
 		if(!count($ids))
+		{
 			return $default_value;
+		}
 		
-		debug_buffer($this->_displaySettings,'AdvancedContent display settings');
 		if(!isset($this->_displaySettings[$item_type][implode('_',$ids)]))
+		{
 			$this->GetAllItemsDisplay($item_type, $content_id, $template_id);
-		debug_buffer($this->_displaySettings,'AdvancedContent display settings');
+		}
 		if(!isset($this->_displaySettings[$item_type][implode('_',$ids)][$item_id]))
+		{
 			$this->_displaySettings[$item_type][implode('_',$ids)][$item_id] = $default_value;
-		debug_buffer($this->_displaySettings,'AdvancedContent display settings');
+		}
 		return $this->_displaySettings[$item_type][implode('_',$ids)][$item_id];
 	}
 	
@@ -829,7 +942,8 @@ class AdvancedContent extends CMSModule
 			$query .= $q[0];
 		}
 		$dbresult = $db->Execute($query, $p);
-		while($dbresult && $row = $dbresult->FetchRow()) {
+		while($dbresult && $row = $dbresult->FetchRow()) 
+		{
 			if($this->GetPreference($item_type.'_display_settings','content') == 'both1'
 			|| $this->GetPreference($item_type.'_display_settings','content') == 'both2') 
 			{
@@ -841,5 +955,212 @@ class AdvancedContent extends CMSModule
 			}
 		}
 	}
+	
+	function GetMultiInputFull($inputs = array()) 
+	{
+		if(!is_array($inputs))
+		{
+			$inputs = $this->CleanArray(explode(",",$inputs));
+		}
+		$db    =& $this->GetDb();
+		$query = "SELECT MULTI_INPUT.*, TPL_ASSOCS.tpl_name FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs MULTI_INPUT
+			LEFT OUTER JOIN ".cms_db_prefix()."module_AdvancedContent_multi_input_tpl_assocs TPL_ASSOCS 
+			ON MULTI_INPUT.input_id = TPL_ASSOCS.input_id";
+		
+		$q     = array();
+		$p     = array();
+		$return_array = array();
+		foreach($inputs as $input_id)
+		{
+			$q[] = "MULTI_INPUT.input_id = ?";
+			$p[] = $input_id;
+		}
+		if(count($p))
+		{
+			$query .= " WHERE " . implode(" OR ", $q);
+		}
+		$dbresult = $db->Execute($query, $p);
+		while($dbresult && $row = $dbresult->FetchRow()) 
+		{
+			$return_array[$row['input_id']] = $row;
+		}
+		return $return_array;
+	}
+	
+	function GetMultiInput($input_id) 
+	{
+		$db       =& $this->GetDb();
+		$query    = "SELECT input_fields FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs WHERE input_id = ? LIMIT 1";
+		$dbresult = $db->Execute($query, array($input_id));
+		if($dbresult && $row = $dbresult->FetchRow()) 
+		{
+			return $row['input_fields'];
+		}
+	}
+	
+	function GetMultiInputList() 
+	{
+		$db       =& $this->GetDb();
+		$query    = "SELECT A.input_id, B.tpl_name FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs A
+			LEFT JOIN ". cms_db_prefix() . "module_AdvancedContent_multi_input_tpl_assocs B
+			ON A.input_id = B.input_id";
+		$dbresult = $db->Execute($query);
+		$return_array = array();
+		while($dbresult && $row = $dbresult->FetchRow()) 
+		{
+			$return_array[] = $row;
+		}
+		return $return_array;
+	}
+	
+	function AddMultiInput($input_id, $input_fields) 
+	{
+		$db    =& $this->GetDb();
+		$query = "SELECT input_id FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs
+			WHERE input_id = ? LIMIT 1";
+		
+		$dbresult = $db->Execute($query, array($input_id));
+		if($dbresult && $row = $dbresult->FetchRow()) 
+		{
+			return false;
+		}
+		
+		$query = "INSERT INTO ". cms_db_prefix() ."module_AdvancedContent_multi_inputs 
+			(input_id, input_fields) VALUES (?,?)";
+		$dbresult = $db->Execute($query, array($input_id, $input_fields));
+		return $dbresult;
+	}
+	
+	function UpdateMultiInput($input_id, $input_fields) 
+	{
+		$db    =& $this->GetDb();
+		$query = "UPDATE ". cms_db_prefix() . "module_AdvancedContent_multi_inputs 
+			SET input_fields = ? WHERE input_id = ? ";
+		$dbresult = $db->Execute($query, array($input_fields, $input_id));
+		return $dbresult;
+	}
+	
+	function UpdateTplAssoc($tpl_type, $input_id, $tpl_name)
+	{
+		$db    =& $this->GetDb();
+		$query = "UPDATE ". cms_db_prefix() . "module_AdvancedContent_".$tpl_type."_tpl_assocs 
+			SET tpl_name = ? WHERE input_id = ? ";
+		$dbresult = $db->Execute($query, array($tpl_name, $input_id));
+		return $dbresult;
+	}
+	
+	function AddTplAssoc($tpl_type, $input_id, $tpl_name)
+	{
+		$db    =& $this->GetDb();
+		$query = "INSERT INTO ". cms_db_prefix() ."module_AdvancedContent_".$tpl_type."_tpl_assocs 
+			(input_id, tpl_name) VALUES (?,?)";
+		$dbresult = $db->Execute($query, array($input_id, $tpl_name));
+		return $dbresult;
+	}
+	
+	function DeleteTplAssoc($tpl_type,$input_ids = array())
+	{
+		$db =& $this->GetDb();
+		if(!is_array($input_ids))
+		{
+			$input_ids = $this->CleanArray(explode(",",$input_ids));
+		}
+		if(!count($input_ids))
+		{
+			return false;
+		}
+		$query = "DELETE FROM ". cms_db_prefix() . "module_AdvancedContent_".$tpl_type."_tpl_assocs WHERE ";
+		$q = array();
+		foreach($input_ids as $_id)
+		{
+			$q[] = "input_id = ?";
+		}
+		$query   .=  implode(" OR ", $q);
+		$dbresult = $db->Execute($query, $input_ids);
+		return $dbresult;
+	}
+	
+	function DeleteMultiInput($input_ids = array())
+	{
+		$db =& $this->GetDb();
+		if(!is_array($input_ids))
+		{
+			$input_ids = $this->CleanArray(explode(",",$input_ids));
+		}
+		if(!count($input_ids))
+		{
+			return false;
+		}
+		$query = "DELETE FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs WHERE ";
+		$q = array();
+		foreach($input_ids as $_id)
+		{
+			$q[] = "input_id = ?";
+		}
+		
+		$query   .=  implode(" OR ", $q);
+		$dbresult = $db->Execute($query, $input_ids);
+		return $dbresult;
+	}
+	
+	function GetTemplates($prefix)
+	{
+		$db     =& $this->GetDb();
+		$query  = "SELECT TPL.template_name, TPL_ASSOCS.* FROM ". cms_db_prefix() . "module_templates TPL 
+			LEFT OUTER JOIN ".cms_db_prefix()."module_AdvancedContent_".$prefix."_tpl_assocs TPL_ASSOCS 
+			ON TPL.template_name = TPL_ASSOCS.tpl_name 
+			WHERE TPL.module_name = ? AND TPL.template_name LIKE ? ";
+		$return_array = array();
+		$dbresult     = $db->Execute($query, array($this->GetName(),$prefix.'_%'));
+		while($dbresult && $row = $dbresult->FetchRow()) 
+		{
+			if(!isset($return_array[$row['template_name']]))
+			{
+				$return_array[$row['template_name']] = array();
+			}
+			$return_array[$row['template_name']]['tpl_name'] = substr($row['template_name'],strlen($prefix.'_'));
+			$return_array[$row['template_name']]['tpl_id']   = $row['template_name'];
+			if(!isset($return_array[$row['template_name']]['tpl_assocs']))
+			{
+				$return_array[$row['template_name']]['tpl_assocs'] = array();
+				$return_array[$row['template_name']]['is_used'] = false;
+			}
+			if($row['input_id'])
+			{
+				$return_array[$row['template_name']]['tpl_assocs'][] = $row['input_id'];
+				$return_array[$row['template_name']]['is_used'] = true;
+			}
+		}
+		return $return_array;
+	}
+	
+	function GetTplList($prefix)
+	{
+		$prefix = trim($prefix,'_') . '_';
+		$db     =& $this->GetDb();
+		$query  = "SELECT template_name FROM ". cms_db_prefix() . "module_templates 
+			WHERE module_name = ? AND template_name LIKE ? ";
+		$return_array = array();
+		$dbresult = $db->Execute($query, array($this->GetName(),$prefix.'%'));
+		while($dbresult && $row = $dbresult->FetchRow()) 
+		{
+			$tpl_name = substr($row['template_name'],strlen($prefix));
+			$return_array[$tpl_name] = $row['template_name'];
+		}
+		return $return_array;
+	}
+	
+	function IsTplUsed($tpl_name, $assoc_type)
+	{
+		$db     =& $this->GetDb();
+		$query  = "SELECT tpl_name FROM ". cms_db_prefix() . "module_AdvancedContent_".$assoc_type."_tpl_assocs 
+			WHERE template_name = ? ";
+		$dbresult = $db->Execute($query, array($tpl_name));
+		if(!$dbresult || !$row = $dbresult->FetchRow()) 
+		{
+			return false;
+		}
+		return true;
+	}
 }
 ?>
