@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.6
+# Version: 0.6.1
 # File   : action.default.php
 #          This file is a modification of the default plugin {content}
 # Purpose: performs the default frontend action if {AdvancedContent} is used.
@@ -20,7 +20,7 @@ if(isset($params['active']) && $this->IsFalse($params['active'])) {
 	return; // don't process inactive blocks
 }
 
-$pageinfo =& $gCms->variables['pageinfo'];
+$pageinfo =& cmsms()->variables['pageinfo'];
 $result   = '';
 
 $block = 'content_en';
@@ -53,11 +53,11 @@ if(isset($params['default']))
 	$defaultValue = trim($params['default']);
 
 $doSmarty = false;
-if(isset($params['smarty']) && $this->IsTrue($params['smarty']) && $gCms->smarty->_tpl_vars['content_obj']->mType == 'content2')
+if(isset($params['smarty']) && $this->IsTrue($params['smarty']) && cmsms()->GetSmarty()->get_template_vars('content_obj')->Type() == 'content2')
 	$doSmarty = true;
 
-if($doSmarty && $gCms->smarty->_tpl_vars['content_obj']->mType == 'content2') {
-	$defaultValue = $gCms->smarty->_tpl_vars['content_obj']->DoSmarty($gCms->smarty->_tpl_vars['content_obj']->_contentBlocks[$block]['default_value']);
+if($doSmarty && cmsms()->GetSmarty()->get_template_vars('content_obj')->Type() == 'content2') {
+	$defaultValue = cmsms()->GetSmarty()->get_template_vars('content_obj')->DoSmarty(cmsms()->GetSmarty()->get_template_vars('content_obj')->_contentBlocks[$block]['default_value']);
 }
 
 $allowNone = true;
@@ -93,7 +93,7 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 	
 	if (!isset($params['block']) && ($id == 'cntnt01' || ($id != '' && $inline == false))) {
 		
-		$cmsmodules = &$gCms->modules;
+		$cmsmodules = &cmsms()->modules;
 		
 		if (isset($cmsmodules)) {
 			
@@ -153,9 +153,7 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 						unset($params['exclude_sufix']);
 						unset($params['include_prefix']);
 						unset($params['include_sufix']);
-						unset($params['mode']);
 						unset($params['lock_input']);
-						unset($params['file_extension']);
 						unset($params['delimiter']);
 						unset($params['items']);
 						unset($params['values']);
@@ -170,12 +168,16 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 						unset($params['translate_labels']);
 						unset($params['translate_values']);
 						
+						unset($params['inputs']);
+						unset($params['input_delimiter']);
+						unset($params['value_delimiter']);
+						
 						$params = array_merge($params, GetModuleParameters($id));
 						
 						// calguy1000 ... increment the modulenum 
 						// if we're not in inlined mode.
 						if( $id != 'cntnt01' ) {
-							++$gCms->variables["modulenum"]; 
+							++cmsms()->variables["modulenum"]; 
 						}
 						
 						$returnid = '';
@@ -201,16 +203,16 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 		}
 	}
 	else {
-		$oldvalue              = $gCms->smarty->caching;
-		$gCms->smarty->caching = false;
-		$contentId             = $pageinfo->content_id;
+		$oldvalue                     = cmsms()->GetSmarty()->caching;
+		cmsms()->GetSmarty()->caching = false;
+		$contentId                    = $pageinfo->content_id;
 		
 		# MLE support
 		if($mle)
 			$contentId .= '-'.$hls;
 		#---
 		
-		$result = $gCms->smarty->fetch(str_replace(' ', '_', 'content:' . $block), '', $contentId);
+		$result = cmsms()->GetSmarty()->fetch(str_replace(' ', '_', 'content:' . $block), '', $contentId);
 		
 		# MLE support
 		if($mle 
@@ -219,60 +221,20 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 		{
 			if($block != 'content'.$mleblock) {
 				$block  = $_block . $mleblockfallback;
-				$result = $gCms->smarty->fetch(str_replace(' ', '_', 'content:' . $block), '', $contentId);
+				$result = cmsms()->GetSmarty()->fetch(str_replace(' ', '_', 'content:' . $block), '', $contentId);
 			}
 			else {
 				$block  = 'content' . $mleblockfallback;
-				$result = $gCms->smarty->fetch(str_replace(' ', '_', 'content:' . $block), '', $contentId);
+				$result = cmsms()->GetSmarty()->fetch(str_replace(' ', '_', 'content:' . $block), '', $contentId);
 			}
 		}
 		#---
 		
-		$gCms->smarty->caching = $oldvalue;
+		cmsms()->GetSmarty()->caching = $oldvalue;
 		
 		if($result == '' && !$allowNone)
 			$result = $defaultValue;
 		
-		# ToDo: test this (especially MLE)
-		if (isset($params['block_type']) && (strtolower($params['block_type'])=='image' || strtolower($params['block_type'])=='file') && $result == '-1' && $gCms->smarty->_tpl_vars['content_obj']->mType == 'content2') {
-			$result = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,$block);
-		}
-		#---
-		
-		if (isset($params['block_type']) && (strtolower($params['block_type'])=='image' || strtolower($params['block_type'])=='file') && $result != '') {
-			$name    = ' name="AdvancedContent'.ucfirst(strtolower($block)).'"';
-			$urlonly = false;
-			$elmId   = ' id="AdvancedContent'.ucfirst(strtolower($block)).'"';
-			$class   = ' class="AdvancedContent'.ucfirst(strtolower($params['block_type'])).'"';
-			$alt     = ' alt="'.ucfirst(strtolower($block)).'"';
-			$width   = '';
-			$height  = '';
-			$title   = '';
-			$text    = ucfirst(strtolower($block));
-			
-			if( isset($params['name']) )    $name    = ' name="'.$params['name'].'"';
-			if( isset($params['class']) )   $class   = ' class="'.$params['class'];
-			if( isset($params['id']) )      $elmId   = ' id="'.$params['id'];
-			if( isset($params['alt']) )     $alt     = ' alt="'.$params['alt'];
-			if( isset($params['width']) )   $width   = ' width="'.$params['width'];
-			if( isset($params['height']) )  $height  = ' height="'.$params['height'];
-			if( isset($params['title']) )   $title   = ' title="'.$params['title'];
-			if( isset($params['text']) )    $text    = $params['text'];
-			if( isset($params['urlonly']) && $this->IsTrue($params['urlonly']))
-				$urlonly = true;
-			
-			if($gCms->smarty->_tpl_vars['content_obj']->mType == 'content2')
-				$result = $gCms->config['uploads_url']. '/' . $result;
-			
-			if( !$urlonly ) {
-				if(strtolower($params['block_type'])=='image') {
-					$result = '<img src="' . $result . '"'.$name.$elmId.$class.$alt.$width.$height.$title.' />';
-				}
-				else if(strtolower($params['block_type'])=='file') {
-					$result = '<a href="' . $result . '"'.$name.$elmId.$class.$title.'>'.$text.'</a>';
-				}
-			}
-		}
 		if (isset($params['block_type']) && strtolower($params['block_type'])=='date' && isset($params['date_format']) && $params['date_format'] != '')
 			$result = strftime($params['date_format'],$result);
 	}
@@ -281,15 +243,15 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 	$access = true;
 	
 	// only process feu_acces if there is a frontendusers module
-	if( $feusers =& $this->GetModuleInstance('FrontEndUsers' ) && $gCms->smarty->_tpl_vars['content_obj']->mType == 'content2') {
+	if( $feusers =& $this->GetModuleInstance('FrontEndUsers' ) && cmsms()->GetSmarty()->get_template_vars('content_obj')->Type() == 'content2') {
 		
-		$feuAccess = $this->CleanArray(explode(';',$gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['feu_access']));
+		$feuAccess = $this->CleanArray(explode(';',cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_access')));
 		
 		// only process if we have selected anything in backend for feu access
 		if(!empty($feuAccess)) {
 			
 			// if page has no parents but inheritance -> remove inheritance (should never happen but just in case)
-			if($gCms->smarty->_tpl_vars['content_obj']->mParentId <= 0 && in_array("-1",$feuAccess)) {
+			if(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId() <= 0 && in_array("-1",$feuAccess)) {
 				foreach($feuAccess as $k=>$v) {
 					if($v=='-1') unset($feuAccess[$k]);
 				}
@@ -298,7 +260,7 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 			// if there still is inheritance ...
 			if(in_array('-1',$feuAccess)) {
 				// ... finally inherit
-				$feuAccess = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,'feu_access',$feuAccess);
+				$feuAccess = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'feu_access',$feuAccess);
 			}
 			
 			// if we have access for certain feu groups only ...
@@ -329,28 +291,28 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 	else {
 		
 		// get the page to redirect to
-		$redirectPage = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['redirect_page'];
+		$redirectPage = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('redirect_page');
 		if($redirectPage == '-1')
-			$redirectPage = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,'redirect_page');
+			$redirectPage = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'redirect_page');
 		
 		// do not redirect to current page -> will result in endless recursive redirection
 		if($redirectPage == $returnid || $redirectPage == $pageinfo->content_id || $redirectPage == $pageinfo->content_alias)
 			$redirectPage = '';
 		
 		// get feu action
-		$feuAction = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['feu_action'];
+		$feuAction = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_action');
 		
 		if($feuAction == '-1')
-			$feuAction = $gCms->smarty->_tpl_vars['content_obj']->InheritParentProp($gCms->smarty->_tpl_vars['content_obj']->mParentId,'feu_action');
+			$feuAction = cmsms()->GetSmarty()->get_template_vars('content_obj')->InheritParentProp(cmsms()->GetSmarty()->get_template_vars('content_obj')->ParentId(),'feu_action');
 		
 		// if we still don't have a redirect page -> do feu action in current page
 		if($redirectPage == '') {
 			
 			// if we want an action (and we have not done this before) ...
-			if($feuAction && $mainContent && !isset($gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['feu_action_flag'])) {
+			if($feuAction && $mainContent && !cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('feu_action_flag')) {
 				// ... set a flag that we already have a login form now (just to prevent to display it again for other content blocks) ...
-				$gCms->smarty->_tpl_vars['content_obj']->AddExtraProperty("feu_action_flag");
-				$gCms->smarty->_tpl_vars['content_obj']->SetPropertyValue("feu_action_flag", true);
+				cmsms()->GetSmarty()->get_template_vars('content_obj')->AddExtraProperty("feu_action_flag");
+				cmsms()->GetSmarty()->get_template_vars('content_obj')->SetPropertyValue("feu_action_flag", true);
 				// ... and finally do feu action
 				return $feusers->DoAction('default', 'cntnt01', array('form'=>'login'), $returnid);
 			}
@@ -364,8 +326,8 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 		else {
 			// get the redirect params
 			$pattern        = '/([\w]+)=(["][^"]*["]|[\'][^\']*[\']|[^\'"\s]*)/';
-			$redirectParams = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['redirect_params'];
-			$evaluateSmarty = $gCms->smarty->_tpl_vars['content_obj']->mProperties->mPropertyValues['evaluate_smarty'];
+			$redirectParams = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('redirect_params');
+			$evaluateSmarty = cmsms()->GetSmarty()->get_template_vars('content_obj')->Properties()->GetValue('evaluate_smarty');
 			if($evaluateSmarty)
 				$redirectParams = $this->ProcessTemplateFromData($redirectParams);
 			
@@ -389,32 +351,33 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 			}
 			else {
 				// ... otherwise just redirect
-				$manager =& $gCms->GetHierarchyManager();
+				$manager =& cmsms()->GetHierarchyManager();
 				$node    =& $manager->sureGetNodeByAlias($redirectPage);
 				$content =& $node->GetContent();
 				if (isset($content) && $url = $content->GetURL()) {
+					$config = cmsms()->GetConfig();
 					if(!empty($_params1) && !empty($_params2)) {
-						if($gCms->config['url_rewriting'] == 'none') {
-							if($content->mDefaultContent)
+						if($config['url_rewriting'] == 'none') {
+							if($content->DefaultContent())
 								$url .= 'index.php?' . implode('&',$_params2);
 							else
 								$url .= '&' . implode('&',$_params2);
 						}
-						else if($gCms->config['url_rewriting'] == 'internal') {
-							if($content->mDefaultContent)
-								$url .= 'index.php/' . implode('/',$_params1) . '/' . $content->mAlias . $gCms->config['page_extension'];
+						else if($config['url_rewriting'] == 'internal') {
+							if($content->DefaultContent())
+								$url .= 'index.php/' . implode('/',$_params1) . '/' . $content->Alias() . $config['page_extension'];
 							else {
-								$url = str_replace($gCms->config['root_url'],
-									$gCms->config['root_url'] . '/'. implode('/',$_params1),
+								$url = str_replace($config['root_url'],
+									$config['root_url'] . '/'. implode('/',$_params1),
 									$url);
 							}
 						}
-						else if($gCms->config['url_rewriting'] == 'mod_rewrite') {
-							$url = str_replace($gCms->config['root_url'],
-								$gCms->config['root_url'] . '/'. implode('/',$_params1),
+						else if($config['url_rewriting'] == 'mod_rewrite') {
+							$url = str_replace($config['root_url'],
+								$config['root_url'] . '/'. implode('/',$_params1),
 								$url);
-							if($content->mDefaultContent)
-								$url .= $content->mAlias . $gCms->config['page_extension'];
+							if($content->DefaultContent())
+								$url .= $content->Alias() . $config['page_extension'];
 						}
 					}
 					redirect($url);
