@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.6
+# Version: 0.6.1
 # File   : action.savePrefs.php
 # Purpose: saves the preferences in the database
 # License: GPL
@@ -15,7 +15,7 @@
 
 if(!isset($gCms)) exit;
 
-if(isset($params['submit'])) 
+if(isset($params['submit']) || isset($params['submit_prefs'])) 
 {
 	if(isset($params['uninstall_action']))
 		$this->SetPreference('uninstall_action', $params['uninstall_action']);
@@ -51,6 +51,10 @@ if(isset($params['item_type']) && isset($params['item_display']))
 {
 	$this->SetItemDisplay($params['item_type'], $params['item_id'], $params['content_id'], $params['template_id'], $params['item_display']);
 }
+if(isset($params['set_default']))
+{
+	$this->SetPreference('default_'.$params['set_default'].'_tpl', $params['tpl_id']);
+}
 if(isset($params['ajax'])) 
 {
 	echo '<div class="pagemcontainer"><p class="pagemessage">'.$this->lang('prefsupdated').'</p></div>';
