@@ -60,6 +60,40 @@ $lang['both1']                          = "template OR page ";
 $lang['both2']                          = "template AND page";
 $lang['content']                        = 'Content';
 $lang['content2']                       = 'Advanced Content';
+$lang['prefs']                          = 'Preferences';
+$lang['multi_input']                    = 'Multi Inputs';
+$lang['multi_input_tpl']                = 'Multi Input Templates';
+$lang['add_multi_input']                = 'Add new multi input';
+$lang['add_multi_input_tpl']            = 'Add new multi input template';
+$lang['input_id']                       = 'Input ID';
+$lang['input_fields']                   = 'Input fields';
+$lang['tpl_name']                       = 'Template name';
+$lang['error_template']                 = 'Template is a required field and may not be empty';
+$lang['error_input_fields']             = "Input fields is a required field and may not be empty.";
+$lang['error_input_id']                 = "No input id given or input id already exists.";
+$lang['error_input_id_exists']          = "Input ID is already in use. Choose a different one. (must be unique)";
+$lang['multi_input_added']              = "Multi Input added.";
+$lang['multi_input_deleted']            = "Multi Input deleted.";
+$lang['multi_input_updated']            = "Multi Input updated.";
+$lang['multi_input_tpl_added']          = "Multi Input template added.";
+$lang['multi_input_tpl_updated']        = "Multi Input template updated.";
+$lang['multi_input_tpl_deleted']        = "Multi Input template deleted.";
+
+$lang['delete_selected']                = "Delete selected items";
+$lang['confirm_delete']                 = "Do you really want do delete this item?";
+$lang['confirm_delete_selected']        = "Do you really want do delete the selected items?";
+$lang['help_tpl_vars']                  = <<<EOT
+<p><strong>Template vars:</strong></p>
+<p><pre><code>{\$inputs}</code></pre> is an array that contains all defined input elements of that multi input block.<br />
+Each input element is an array that contains all its params. <br />
+See module help for more info.<br />
+Additional param is "input" that will print out the input element.<br />
+To access the params use the dot syntax.<br />
+Example:</p>
+<pre><code>{foreach from=\$inputs item=elm}
+	{\$elm.label}:&nbsp;{\$elm.input}&lt;br /&gt;
+{/foreach}</code></pre>
+EOT;
 $lang['help'] = <<<EOT
 <br />
 <h3>What does this do?</h3>
@@ -149,9 +183,9 @@ in backend...</p>
 <p><strong>Advanced params:</strong></p>
 <ul>
 	<li>
-		<em>(optional)</em> <tt>block_type</tt> (text,checkbox,dropdown,select_multiple,date) 
+		<em>(optional)</em> <tt>block_type</tt> (text,checkbox,dropdown,select_multiple,date,multi_input) 
 		<ul>
-			<li>Allows you to specify what content control type is used in the back end. Supports block-parameters to include additional options.</li>
+			<li>Allows you to specify what content control type is used in the back end.</li>
 		</ul>
 		<br />
 	</li>
@@ -422,6 +456,103 @@ in backend...</p>
 		<br />
 	</li>
 </ul>
+<p><strong>Params of blocktype "multi_input":</strong></p>
+<ul>
+	<li>
+		<em>(optional)</em> <tt>inputs</tt> (csv of input ids you created in the backend) 
+		<br /><br />
+	</li>
+	<li>
+		<em>(optional)</em> <tt>value_delimiter</tt> (any string) 
+		<ul>
+			<li>
+				This defines a string that devides the values of the inputs of one multi_input when stored in the database.<br />
+				Default is "&lt;!-- multi_input_value_dellimiter --&gt;"
+			</li>
+		</ul>
+		<br />
+	</li>
+	<li>
+		<em>(optional)</em> <tt>input_delimiter</tt> (any string) 
+		<ul>
+			<li>
+				This defines a string that devides the multi_inputs you defined for this content block when stored in the database.<br />
+				Default is "&lt;!-- multi_input_dellimiter --&gt;"
+			</li>
+		</ul>
+		<br />
+	</li>
+	<li>
+		<p><strong>What is a multi_input for?</strong></p>
+		<p>A multi_input block is a content block that consists of different input fields. <br />
+		You can define them in the module administration using the same syntax you use in a template when defining a content block.<br />
+		Multi inputs can be used if you want to store different values in one content block and provide different input types for each values.<br />
+		This can be usefull if you want to create a dropdown to select a module to be shown in frontend and text input to define the module parameters.<br />
+		Example for a multi_input in page template:</p>
+		<pre>
+		<code>
+		{content block="module" label="Page modules" block_type="multi_input" inputs="module,module,module,module"}
+		</code>
+		</pre>
+		<p>Example for the definition of the multi_input named "module":</p>
+		<pre>
+		<code>
+		{content block="module selection" block_type="dropdown" items="|News|Gallery|Menu"}
+		{content block="module params" block_type="text" oneline=true}
+		</code>
+		</pre>
+		<p>What happens if you edit a page?</p>
+		<p>It will show you a fieldset with legend "Page modules". <br />
+		Inside this fieldset it shows the multi_input named "module" four times.<br />
+		That means you see four lines with two input fields. A dropdown and a text input.</p>
+		<p>What happens if you save a page?</p>
+		<p>The module stores the values as one single content property (aka contentblock) and separates the inputs by a given delimiter.<br />
+		Let's assume you select the News module four times with different module params like category="1", category="2", category="3", category="4".<br />
+		In the database it stores this string:</p>
+		<pre>
+		<code>
+		News&lt;!-- multi_input_value_delimiter --&gt;category="1"&lt;!-- multi_input_delimiter --&gt;<br />
+		News&lt;!-- multi_input_value_delimiter --&gt;category="2"&lt;!-- multi_input_delimiter --&gt;<br />
+		News&lt;!-- multi_input_value_delimiter --&gt;category="3"&lt;!-- multi_input_delimiter --&gt;<br />
+		News&lt;!-- multi_input_value_delimiter --&gt;category="4"
+		</code>
+		</pre>
+		<p>In your page template you can explode the content by the delimiters and call the selected modules.</p>
+		<p>Full Example:</p>
+		<pre>
+		<code>
+		{* define the content block *}
+		{content block="my_modules" block_type="multi_input" inputs="Module,Module,Module,Module" assign="modules"}
+		
+		{* explode block content in an array to get the input groups *}
+		{assign var=modules value="&lt;!-- multi_input_delimiter --&gt;"|explode:\$modules}
+		
+		{* loop through the selected modules *}
+		{foreach from=\$modules item="module"}
+			{if \$module != ''}
+			
+				{* explode the input values in modulname and module parameters *}
+				{assign var=module_items value="&lt;!-- multi_input_value_delimiter --&gt;"|explode:\$module}
+				
+				{if\$module_items[0] != ''}
+				
+					{* call the module *}
+					{if isset(\$module_items[1])}
+						{eval var=\$smarty.ldelim|cat:'cms_module module="'|cat:\$module_items[0]|cat:'" '|cat:\$module_items[1]|cat:\$smarty.rdelim}
+					{else}
+						{eval var=\$smarty.ldelim|cat:'cms_module module="'|cat:\$module_items[0]|cat:'"'|cat:\$smarty.rdelim}
+					{/if}
+					
+				{/if}
+				
+			{/if}
+		
+		{/foreach}
+		</code>
+		</pre>
+	</li>
+</ul>
+
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
@@ -451,6 +582,21 @@ $lang['changelog'] = <<<EOT
 <br />
 <p><strong>Module releases</strong>...</p>
 <ul>
+	<li><p><strong>0.6.1 (Oct 2010):</strong></p>
+		<ul>
+			<li><p>Bugfixes:</p>
+				<ul>
+					<li><p>- several bugfixes</p></li>
+					<li><p>- compatibility bugfixes for CMSms 1.9</p></li>
+				</ul>
+			</li>
+			<li><p>Features:</p>
+				<ul>
+					<li><p>- added block_type multi_input</p></li>
+				</ul>
+			</li>
+		</ul>
+	</li>
 	<li><p><strong>0.6 (Oct 2010):</strong></p>
 		<ul>
 			<li><p>Bugfixes:</p>
