@@ -7,7 +7,7 @@ $lang['postinstall'] = 'Le module AdvancedContent %s est install&eacute; ';
 $lang['postuninstall'] = 'Le module AdvancedContent %s est d&eacute;sinstall&eacute;';
 $lang['confirmuninstall'] = '&Ecirc;tes vous certain de vouloir d&eacute;sinstaller le module AdvancedContent ?';
 $lang['notice_duplicatecontent'] = '<em><strong>Attention:</strong> Ce bloc est utilis&eacute; &agrave; de multiples reprises dans le gabarit. Vous verrez ici uniquement le premier bloc.</em>';
-$lang['error_basicattrib'] = '<em><strong>Attention:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />This block is disabled. Check your page template and chose a different value of param &#039;block&#039;.</em>';
+$lang['error_basicattrib'] = '<em><strong>Notice:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />Ce bloc est inactif. V&eacute;rifiez votre gabarit de page et choisissez une valeur diff&eacute;rente du param&egrave;tre &#039;block&#039;.</em>';
 $lang['error_expiredate'] = 'La date de fin doit &ecirc;tre sup&eacute;rieure &agrave; la date de d&eacute;but';
 $lang['youareintext'] = 'R&eacute;pertoire courant';
 $lang['dimensions'] = 'Taille de l&#039;image';
@@ -689,9 +689,9 @@ $lang['changelog'] = '<br />
 	</li>
 </ul>
 <br />';
-$lang['utma'] = '156861353.276912794.1247063679.1286399692.1286476268.60';
-$lang['utmz'] = '156861353.1286476268.60.24.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
-$lang['qca'] = 'P0-483686814-1251229608352';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1949673112.1265210769.1286953600.1286956518.214';
+$lang['utmz'] = '156861353.1286956518.214.40.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,48121.0.html|utmcmd=referral';
+$lang['qca'] = 'P0-1075820551-1265210768764';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
