@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.6
+# Version: 0.6.1
 # File   : method.uninstall.php
 # Purpose: uninstalls the module, removes tables, preferences, permissions... 
 # License: GPL
@@ -23,6 +23,10 @@ $sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_message
 $dict->ExecuteSQLArray($sqlarray);
 $sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_groupdisplay" );
 $dict->ExecuteSQLArray($sqlarray);
+$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_multi_inputs" );
+$dict->ExecuteSQLArray($sqlarray);
+$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_multi_input_tpl_assocs" );
+$dict->ExecuteSQLArray($sqlarray);
 
 if($this->GetPreference('uninstall_action') != '') {
 	switch($this->GetPreference('uninstall_action')) {
@@ -79,9 +83,13 @@ if($this->GetPreference('uninstall_action') != '') {
 $this->RemovePermission('Manage AdvancedContent');
 $this->RemovePermission('Manage All AdvancedContent Blocks');
 $this->RemovePermission('Manage AdvancedContent Options');
+$this->RemovePermission('Manage AdvancedContent MultiInputs');
+$this->RemovePermission('Manage AdvancedContent MultiInput Templates');
 
 $this->RemoveEventHandler( 'Core', 'ContentPostRender');
 
+$this->DeleteTemplate();
+
 // remove preferences
 $this->RemovePreference();
 
