@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.6
+# Version: 0.6.1
 # File   : method.upgrade.php
 # Purpose: performs a module upgrade
 # License: GPL
@@ -161,6 +161,40 @@ switch($current_version)
 		$dict->ExecuteSQLArray($sqlarray);
 		
 		$current_version = '0.6';
+		
+	case '0.6':
+		
+		$taboptarray = array('mysql' => 'TYPE=MyISAM');
+		$dict        = NewDataDictionary( $db );
+		
+		// multiple inputs
+		$flds = "input_id C(64) KEY, input_fields X";
+		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_AdvancedContent_multi_inputs", 
+			$flds, $taboptarray);
+		$dict->ExecuteSQLArray($sqlarray);
+		
+		// multiple input tpl assocs
+		$flds = "input_id C(64), tpl_name X";
+		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_AdvancedContent_multi_input_tpl_assocs", 
+			$flds, $taboptarray);
+		$dict->ExecuteSQLArray($sqlarray);
+		
+		$this->CreatePermission('Manage AdvancedContent MultiInputs', 'Manage AdvancedContent MultiInputs');
+		$this->CreatePermission('Manage AdvancedContent MultiInput Templates', 'Manage AdvancedContent MultiInput Templates');
+		$this->SetTemplate('multi_input_SampleTemplate',
+'<div class="pageoverflow">
+<p>
+{foreach from=$inputs item=elm}
+	{$elm.label}:&nbsp;{$elm.input}&nbsp;
+{/foreach}
+</p>
+</div>');
+		$this->AddMultiInput('SampleInput','
+{content block="module_select" label="Select a module" block_type="dropdown" items="|News|Menu" values="|News|MenuManager"}
+{content block="module_params" label="Enter module parameters here" block_type="text" oneline=true size="64"}');
+		$this->AddTplAssoc('multi_input', 'SampleInput', 'multi_input_SampleTemplate');
+		$this->SetPreference('default_multi_input_tpl', 'multi_input_SampleTemplate');
+
 }
 
 ?>
